@@ -4,7 +4,7 @@ from django.contrib import admin
 
 
 class ModelAdmin(admin.ModelAdmin):
-    """ deletion of top level objects is evil """
+    """deletion of top level objects is evil"""
 
     actions = None
 
@@ -12,7 +12,7 @@ class ModelAdmin(admin.ModelAdmin):
         return False
 
     # we probably don't want to add anything through the interface
-    def has_add_permission(self, request):
+    def has_add_permission(self, request, obj=None):
         return False
 
     # To ignore `DisallowedModelAdminLookup` error because of non
@@ -22,7 +22,7 @@ class ModelAdmin(admin.ModelAdmin):
 
 
 class ReadOnlyTabularInline(admin.TabularInline):
-    def has_add_permission(self, request):
+    def has_add_permission(self, request, obj=None):
         return False
 
     can_delete = False
@@ -35,7 +35,7 @@ class IdentifierInline(admin.TabularInline):
     verbose_name = "ID from another system"
     verbose_name_plural = "IDs from other systems"
 
-    def has_add_permission(self, request):
+    def has_add_permission(self, request, obj=None):
         return False
 
 
@@ -44,13 +44,6 @@ class LinkInline(admin.TabularInline):
     extra = 0
 
 
-class ContactDetailInline(admin.TabularInline):
-    fields = ("type", "value", "note", "label")
-    extra = 0
-    verbose_name = "Piece of contact information"
-    verbose_name_plural = "Contact information"
-
-
 class OtherNameInline(admin.TabularInline):
     extra = 0
     verbose_name = "Alternate name"
