@@ -6,7 +6,6 @@ from .base import (
     ModelAdmin,
     ReadOnlyTabularInline,
     IdentifierInline,
-    ContactDetailInline,
     OtherNameInline,
 )
 
@@ -19,8 +18,9 @@ class PersonNameInline(OtherNameInline):
     model = models.PersonName
 
 
-class PersonContactDetailInline(ContactDetailInline):
-    model = models.PersonContactDetail
+class PersonOfficeInline(ReadOnlyTabularInline):
+    readonly_fields = ("classification", "address", "voice", "fax", "name")
+    model = models.PersonOffice
 
 
 class PersonLinkInline(ReadOnlyTabularInline):
@@ -35,11 +35,12 @@ class PersonSourceInline(ReadOnlyTabularInline):
 
 class MembershipInline(ReadOnlyTabularInline):
     model = models.Membership
-    readonly_fields = ("organization", "post", "role", "start_date")
+    readonly_fields = ("organization", "person", "post", "role", "start_date")
     fields = ("id",) + readonly_fields + ("end_date",)
     exclude = ("id",)
     extra = 0
     can_delete = False
+    ordering = ("end_date",)
 
 
 # TODO field locking
@@ -62,7 +63,7 @@ class PersonAdmin(ModelAdmin):
     inlines = [
         PersonIdentifierInline,
         PersonNameInline,
-        PersonContactDetailInline,
+        PersonOfficeInline,
         PersonLinkInline,
         PersonSourceInline,
         MembershipInline,
