@@ -2,11 +2,9 @@ from django.db import models
 from django.contrib.postgres.fields import ArrayField
 from .base import (
     OCDBase,
-    LinkBase,
     OCDIDField,
     RelatedBase,
     RelatedEntityBase,
-    MimetypeLinkBase,
 )
 from .jurisdiction import Jurisdiction
 from .bill import Bill
@@ -63,7 +61,15 @@ class Event(OCDBase):
     all_day = models.BooleanField(default=False)
     status = models.CharField(max_length=20, choices=EVENT_STATUS_CHOICES)
     location = models.ForeignKey(EventLocation, null=True, on_delete=models.SET_NULL)
+    upstream_id = models.CharField(max_length=300, blank=True)
+
+    # internal fields
     dedupe_key = models.CharField(max_length=500, null=True)
+    deleted = models.BooleanField(default=False)
+
+    # compound fields
+    sources = models.JSONField(default=list, blank=True)
+    links = models.JSONField(default=list, blank=True)
 
     def __str__(self):
         return "{0} ({1})".format(self.name, self.start_date)
@@ -78,6 +84,7 @@ class EventMedia(EventMediaBase):
     classification = models.CharField(
         max_length=50, choices=EVENT_MEDIA_CLASSIFICATION_CHOICES, blank=True
     )
+    links = models.JSONField(default=list, blank=True)
 
     def __str__(self):
         return "%s for %s" % (self.note, self.event)
@@ -86,18 +93,6 @@ class EventMedia(EventMediaBase):
         db_table = "opencivicdata_eventmedia"
 
 
-class EventMediaLink(MimetypeLinkBase):
-    media = models.ForeignKey(
-        EventMedia, related_name="links", on_delete=models.CASCADE
-    )
-
-    def __str__(self):
-        return "{0} for {1}".format(self.url, self.media.event)
-
-    class Meta:
-        db_table = "opencivicdata_eventmedialink"
-
-
 class EventDocument(RelatedBase):
     event = models.ForeignKey(Event, related_name="documents", on_delete=models.CASCADE)
     note = models.CharField(max_length=300)
@@ -105,6 +100,7 @@ class EventDocument(RelatedBase):
     classification = models.CharField(
         max_length=50, choices=EVENT_DOCUMENT_CLASSIFICATION_CHOICES, blank=True
     )
+    links = models.JSONField(default=list, blank=True)
 
     def __str__(self):
         tmpl = "{doc.note} for event {doc.event}"
@@ -114,32 +110,6 @@ class EventDocument(RelatedBase):
         db_table = "opencivicdata_eventdocument"
 
 
-class EventDocumentLink(MimetypeLinkBase):
-    document = models.ForeignKey(
-        EventDocument, related_name="links", on_delete=models.CASCADE
-    )
-
-    def __str__(self):
-        return "{0} for {1}".format(self.url, self.document)
-
-    class Meta:
-        db_table = "opencivicdata_eventdocumentlink"
-
-
-class EventLink(LinkBase):
-    event = models.ForeignKey(Event, related_name="links", on_delete=models.CASCADE)
-
-    class Meta:
-        db_table = "opencivicdata_eventlink"
-
-
-class EventSource(LinkBase):
-    event = models.ForeignKey(Event, related_name="sources", on_delete=models.CASCADE)
-
-    class Meta:
-        db_table = "opencivicdata_eventsource"
-
-
 class EventParticipant(RelatedEntityBase):
     event = models.ForeignKey(
         Event, related_name="participants", on_delete=models.CASCADE
@@ -210,21 +180,10 @@ class EventAgendaMedia(EventMediaBase):
         EventAgendaItem, related_name="media", on_delete=models.CASCADE
     )
     classification = models.CharField(max_length=100, blank=True, default="")
+    links = models.JSONField(default=list, blank=True)
 
     def __str__(self):
         return "{0} for {1}".format(self.note, self.agenda_item)
 
     class Meta:
         db_table = "opencivicdata_eventagendamedia"
-
-
-class EventAgendaMediaLink(MimetypeLinkBase):
-    media = models.ForeignKey(
-        EventAgendaMedia, related_name="links", on_delete=models.CASCADE
-    )
-
-    def __str__(self):
-        return "{0} for {1}".format(self.url, self.media)
-
-    class Meta:
-        db_table = "opencivicdata_eventagendamedialink"
